local mod = ...




-- Asset -------------------------------------------------------------------------------------
mod:registerAssetId("models/Idler2.fbx/Prefab/ArrowPart/Arrow", "PREFAB_IDLER_ARROW")
mod:registerAssetId("models/Idler2.fbx/Prefab/StoolPart", "PREFAB_IDLER_STOOL")



-- Building Asset Processor
mod:registerAssetProcessor("models/Idler2.fbx", { DataType = "BUILDING_ASSET_PROCESSOR" })



-- Resource: Nothing -------------------------------------------------------------------------------------
mod:registerAssetId("icons/Idleness.png", "ICON_IDLENESS")

mod:register({
	DataType = "RESOURCE",
	Id = "RESOURCE_IDLENESS",
	ResourceName = "RESOURCE_IDLENESS_NAME",
	Icon = "ICON_IDLENESS",
	ResourceTypeList = { "RESOURCE" },
	IsTradable = false,
    DisplayInInventory = false,
    DisplayInToolbar = false
})



-- Resource Container -------------------------------------------------------------------------------------
mod:registerPrefabComponent( "models/Idler2.fbx/Prefab/ArrowPart/Arrow", {
    DataType = "COMP_RESOURCE_CONTAINER",
    ResourceData = "RESOURCE_IDLENESS",
    IsReplenishable = true,
	ReplenishDurationInDays = 3,
	ReplenishQuantity = 1,
    ResourceValue = 1.0, -- how many are gathered with each pick
    AvailableQuantity = 1, -- maximum container stock
    Radius = 0, -- distance from container that the villager will stand to pick
    IsDestroyWhenEmpty = false
    -- HasMaximumWorkstation = true -- not sure what this does, hoping it keeps them from using each other's patrol points
})



-- Plantable -------------------------------------------------------------------------------------
mod:registerPrefabComponent("models/Idler2.fbx/Prefab/ArrowPart/Arrow", { DataType = "COMP_PLANTABLE", MinSpaceBetweenPlant = 1.0 })



-- Building: Idler -------------------------------------------------------------------------------------
mod:register({
	DataType = "BUILDING", 
	Id = "BUILDING_IDLER",
	Name = "BUILDING_IDLER_NAME",
	Description = "BUILDING_IDLER_DESC",
	BuildingType = "DECORATION",
    AssetCoreBuildingPart = "BUILDING_PART_MONUMENT_POLE",
	BuildingPartSetList = {
		{
			Name = "BUILDING_SET_IDLER1_NAME",
			BuildingPartList = { 
				"BUILDING_PART_IDLER_STOOL",
				"BUILDING_PART_IDLER_ARROW",
			}
		},
    },
	-- RequiredPartList = {
	-- 	{ Category = "CORE", Min = 1, Max = 1 },
	-- },
	-- VillagerRequired = { Status = "SERF", Quantity = 10 },
	IsEditable = true
})



-- Building Part: Stool -------------------------------------------------------------------------------------
mod:register({
	DataType = "BUILDING_PART",
	Id = "BUILDING_PART_IDLER_STOOL",
	Name = "BUILDING_PART_IDLER_STOOL_NAME", 
	Description = "BUILDING_PART_IDLER_STOOL_DESC", 
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_DEFAULT",
		CoreObjectPrefab = "PREFAB_IDLER_STOOL"
	},
	BuildingZone = { 
        ZoneEntryList = {
            { 
                Polygon = polygon.createCircle( 0.5, {0, 0}, 12 ),
                Type = { DEFAULT = true, NAVIGABLE = true, GRASS_CLEAR = false } 
			}, 
            { 
                Polygon = polygon.createCircle( 0.25, {0, 0}, 12 ),
                Type = { DEFAULT = true, NAVIGABLE = true, GRASS_CLEAR = true } 
			}, 
		}
	},
	AssetBuildingFunction = "BUILDING_FUNCTION_IDLER",
	Cost = {
	}
})



-- Building Part: Arrow -------------------------------------------------------------------------------------
mod:register({
	DataType = "BUILDING_PART",
	Id = "BUILDING_PART_IDLER_ARROW",
	Name = "BUILDING_PART_IDLER_ARROW_NAME", 
	Description = "BUILDING_PART_IDLER_ARROW_DESC", 
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_DEFAULT",
		CoreObjectPrefab = "PREFAB_IDLER_ARROW"
	},
	IsVisibleWhenBuilt = false,
	IsMovableWhenBuilt = true
})



-- Job: Idler -------------------------------------------------------------------------------------
mod:register({
	DataType = "JOB",
	Id = "JOB_IDLER",
	JobName = "JOB_IDLER_NAME",
	JobDescription = "JOB_IDLER_DESC",
	IsLockedByDefault = false,
	DefaultBehavior = "BEHAVIOR_GATHER",
    ProductionDelay = 60.0,
	AssetJobProgression = "DEFAULT_JOB_PROGRESSION",
	CharacterSetup = {
		WalkAnimation = "WALKING",
		IdleAnimation = "IDLE"
	}
})

mod:override({
    Id = "NEWCOMER",
    CompatibleJobList = {
        Action = "APPEND",
        "JOB_IDLER"
    }
})

mod:override({
    Id = "SERF",
    CompatibleJobList = {
        Action = "APPEND",
        "JOB_IDLER"
    }
})

mod:override({
    Id = "COMMONER",
    CompatibleJobList = {
        Action = "APPEND",
        "JOB_IDLER"
    }
})

mod:override({
    Id = "CITIZEN",
    CompatibleJobList = {
        Action = "APPEND",
        "JOB_IDLER"
    }
})



-- Building Function: Idler -------------------------------------------------------------------------------------
mod:register({
    DataType = "BUILDING_FUNCTION_WORKPLACE",
    Id = "BUILDING_FUNCTION_IDLER",
    Name = "BUILDING_FUNCTION_IDLER_NAME",
    WorkerCapacity = 1,
    RelatedJob = { 
        Job = "JOB_IDLER", 
        Behavior = "BEHAVIOR_GATHER"
    },
    InputInventoryCapacity = {
		{ Resource = "RESOURCE_IDLENESS", Quantity = 1 },
	},
    ResourceListNeeded = {
		{ Resource = "RESOURCE_IDLENESS", Quantity = 1 }, 
	},
	ResourceProduced = {
        -- { Resource = "RESOURCE_IDLENESS", Quantity = 1 },
    }
})
